Trait photondb::env::PositionalReaderExt
source · pub trait PositionalReaderExt {
type ReadExactAt<'a>: Future<Output = Result<()>> + 'a
where
Self: 'a;
fn read_exact_at<'a>(
&'a self,
buf: &'a mut [u8],
pos: u64
) -> Self::ReadExactAt<'a>;
}Expand description
Extension methods for PositionalReader.
Required Associated Types
sourcetype ReadExactAt<'a>: Future<Output = Result<()>> + 'a
where
Self: 'a
type ReadExactAt<'a>: Future<Output = Result<()>> + 'a
where
Self: 'a
A future that resolves to the result of Self::read_exact_at.
Required Methods
sourcefn read_exact_at<'a>(
&'a self,
buf: &'a mut [u8],
pos: u64
) -> Self::ReadExactAt<'a>
fn read_exact_at<'a>(
&'a self,
buf: &'a mut [u8],
pos: u64
) -> Self::ReadExactAt<'a>
Reads the exact number of bytes from this object at pos to fill buf.